==> leaflet-8.x-1.34.tar.gz: leaflet/modules/leaflet_markercluster/leaflet_markercluster.drupal.js <==
/**
 * We are overriding the adding features functionality of the Leaflet module.
 */

(function ($) {
  Drupal.Leaflet.prototype.add_features = function (mapid, features, initial) {

    var leaflet_markercluster_options = this.settings.leaflet_markercluster.options && this.settings.leaflet_markercluster.options.length > 0 ? JSON.parse(this.settings.leaflet_markercluster.options) : {};
    var cluster_layer = new L.MarkerClusterGroup(leaflet_markercluster_options);
    var collections_cluster_layers = {};
    for (var i = 0; i < features.length; i++) {
      var feature = features[i];
      var lFeature;

      // dealing with a layer group
      if (feature.group) {
        var lGroup = this.create_feature_group(feature);
        for (var groupKey in feature.features) {
          var groupFeature = feature.features[groupKey];
          lFeature = this.create_feature(groupFeature);
          if (lFeature !== undefined) {
            if (lFeature.setStyle) {
              feature.path = feature.path ? JSON.parse(feature.path) : {};
              lFeature.setStyle(feature.path);
            }
            if (groupFeature.popup) {
              lFeature.bindPopup(groupFeature.popup, {
                maxWidth: "auto"
              });
            }
            lGroup.addLayer(lFeature);
          }
        }

        // @todo we need to correctly handle the groups here
        cluster_layer.addLayer(lGroup);
      }
      else {
        lFeature = this.create_feature(feature);
        if (lFeature !== undefined) {
          if (lFeature.setStyle) {
            feature.path = feature.path ? JSON.parse(feature.path) : {};
            lFeature.setStyle(feature.path);
            collections_cluster_layers[i] = new L.MarkerClusterGroup(leaflet_markercluster_options);
            collections_cluster_layers[i].addLayer(lFeature);
            if (feature.popup) {
              collections_cluster_layers[i].bindPopup(feature.popup, {
                maxWidth: "auto"
              });
            }

          }
          else {
            // this.lMap.addLayer(lFeature);
            cluster_layer.addLayer(lFeature);
            if (feature.popup) {
              lFeature.bindPopup(feature.popup, {
                maxWidth: "auto"
              });
            }
          }
        }
      }

      // Allow others to do something with the feature that was just added to the map
      $(document).trigger('leaflet.feature', [lFeature, feature, this]);
    }

    // Add all markers to the map
    this.lMap.addLayer(cluster_layer)

    for (var i in collections_cluster_layers) {
      if(collections_cluster_layers.hasOwnProperty(i)) {
        this.lMap.addLayer(collections_cluster_layers[i])
      }
    }

    // Allow plugins to do things after features have been added.
    $(document).trigger('leaflet.features', [initial || false, this])
  };

})(jQuery);

==> leaflet-8.x-1.37.tar.gz: leaflet/modules/leaflet_markercluster/leaflet_markercluster.drupal.js <==
/**
 * We are overriding the adding features functionality of the Leaflet module.
 */

(function ($) {
  Drupal.Leaflet.prototype.add_features = function (mapid, features, initial) {

    var leaflet_markercluster_options = this.settings.leaflet_markercluster.options && this.settings.leaflet_markercluster.options.length > 0 ? JSON.parse(this.settings.leaflet_markercluster.options) : {};
    var cluster_layer = new L.MarkerClusterGroup(leaflet_markercluster_options);
    var collections_cluster_layers = {};
    for (var i = 0; i < features.length; i++) {
      var feature = features[i];
      var lFeature;

      // dealing with a layer group
      if (feature.group) {
        var lGroup = this.create_feature_group(feature);
        for (var groupKey in feature.features) {
          var groupFeature = feature.features[groupKey];
          lFeature = this.create_feature(groupFeature);
          if (lFeature !== undefined) {
            if (lFeature.setStyle) {
              feature.path = feature.path ? JSON.parse(feature.path) : {};
              lFeature.setStyle(feature.path);
            }
            if (groupFeature.popup) {
              lFeature.bindPopup(groupFeature.popup);
            }
            lGroup.addLayer(lFeature);
          }
        }

        // @todo we need to correctly handle the groups here
        cluster_layer.addLayer(lGroup);
      }
      else {
        lFeature = this.create_feature(feature);
        if (lFeature !== undefined) {
          if (lFeature.setStyle) {
            feature.path = feature.path ? JSON.parse(feature.path) : {};
            lFeature.setStyle(feature.path);
            collections_cluster_layers[i] = new L.MarkerClusterGroup(leaflet_markercluster_options);
            collections_cluster_layers[i].addLayer(lFeature);
            if (feature.popup) {
              collections_cluster_layers[i].bindPopup(feature.popup);
            }

          }
          else {
            // this.lMap.addLayer(lFeature);
            cluster_layer.addLayer(lFeature);
            if (feature.popup) {
              lFeature.bindPopup(feature.popup);
            }
          }
        }
      }

      // Allow others to do something with the feature that was just added to the map
      $(document).trigger('leaflet.feature', [lFeature, feature, this]);
    }

    // Add all markers to the map
    this.lMap.addLayer(cluster_layer)

    for (var i in collections_cluster_layers) {
      if(collections_cluster_layers.hasOwnProperty(i)) {
        this.lMap.addLayer(collections_cluster_layers[i])
      }
    }

    // Allow plugins to do things after features have been added.
    $(document).trigger('leaflet.features', [initial || false, this])
  };

})(jQuery);
